#
# spec file for package kf6-kdeclarative
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname kdeclarative
# Full KF6 version (e.g. 6.9.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-kdeclarative
Version:        6.9.0
Release:        1.1
Summary:        Integration of QML and KDE workspaces
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Config) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6I18n) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6ShaderTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}

%description
KDeclarative provides integration of QML and KDE workspaces.

%package -n libKF6CalendarEvents6
Summary:        Integration of QML and KDE workspaces
Recommends:     kf6-kdeclarative-imports = %{version}

%description -n libKF6CalendarEvents6
KDeclarative provides integration of QML and KDE workspaces.

%package imports
Summary:        KDeclarative QML imports
Requires:       kf6-kirigami-imports >= %{_kf6_bugfix_version}

%description imports
KDeclarative provides integration of QML and KDE workspaces.

%package devel
Summary:        Integration of QML and KDE workspaces: Build Environment
Requires:       libKF6CalendarEvents6 = %{version}
Requires:       cmake(KF6Config) >= %{_kf6_bugfix_version}
Requires:       cmake(KF6CoreAddons) >= %{_kf6_bugfix_version}
Requires:       cmake(Qt6Quick) >= %{qt6_version}

%description devel
KDeclarative provides integration of QML and KDE workspaces.
Development files.

%lang_package -n libKF6CalendarEvents6

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang kdeclarative6

%ldconfig_scriptlets -n libKF6CalendarEvents6

%files -n libKF6CalendarEvents6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6CalendarEvents.so.*

%files imports
%dir %{_kf6_qmldir}/org/kde/private
%{_kf6_qmldir}/org/kde/draganddrop/
%{_kf6_qmldir}/org/kde/graphicaleffects/
%{_kf6_qmldir}/org/kde/kquickcontrols/
%{_kf6_qmldir}/org/kde/kquickcontrolsaddons/
%{_kf6_qmldir}/org/kde/private/kquickcontrols/

%files devel
%doc %{_kf6_qchdir}/KF6Declarative.*
%{_kf6_cmakedir}/KF6Declarative/
%{_kf6_includedir}/KDeclarative/
%{_kf6_libdir}/libKF6CalendarEvents.so

%files -n libKF6CalendarEvents6-lang -f kdeclarative6.lang

%changelog
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * It compiles fine without deprecated methods
  * ci: add Alpine/musl job
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * Update version to 6.8.0
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * qpixmapitem: prevent a crash when there are no window yet
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * QPixmapItem: Adjust rendering to dpr positioning (kde#481219)
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * KeySequenceItem: be Accessible.Button, not Checkbox
  * Update version to 6.5.0
  * KeySequenceItem: Use KMessageDialog for displaying conflict messages
  * kquickcontrols: Drop validation code from KeySequenceHelper
  * kquickcontrols: Use KeySequenceValidator in KeySequenceItem (kde#483199)
  * kquickcontrols: Introduce private KeySequenceValidator type
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * Add missing copyright to KeySequenceItem
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * KeySequenceItem: Fix height management
  * Remove useless note from metainfo
  * Fix tier in metainfo
  * Remove explicit maintainer from metainfo
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- No code change since 6.1.0
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * Remove redundant QML_ELEMENT in KDeclarativeMouseEvent and WheelEvent
  * Don't use kwidgetsaddons on Android
  * Refactor kglobalaccel check
  * Don't use kglobalaccel on Android
  * Mark Android as supported
  * Add Android CI
  * Add dependency to QML module
  * kquickcontrolsaddons: Drop QML import versions from doc example
  * kquickcontrols: Remove superfluous no-op assignment
  * kquickcontrols: Replace superfluous Text item and a semi-broken expression
  * kquickcontrols: Reduce superfluous ternary
  * kquickcontrols: Declare type of __previousSequence property as a string
  * kquickcontrols: Uplift previousSequence property to the root component
  * kquickcontrols: Drop QML import versions, fix up code style
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kdeclarative
